@@ -68,9 +68,13 @@ class ADURecord(object):
         return [cls(x) for x in _read_adu(open(filename))]
 
     @staticmethod
-    def to_file(records, file):
+    def to_file(records, file, truncate_long_values=False):
         """
-        writes the data given in a list of ADURecord objects to the given filename or file.
+        writes the data given in a list of ADURecord objects to the given
+        filename or file.
+        
+        if truncate_long_fields is False, raises an exception if any are too
+        long.
         """
         havefile=hasattr(file, 'write')
         if havefile:
@@ -79,7 +83,7 @@ class ADURecord(object):
         else:
             fp=open(file, 'wb')
         for r in records:
-            _writeline(fp, r._data)
+            _writeline(fp, r._data, truncate_long_values)
         if not havefile:
             fp.close()
         else:
@@ -90,8 +94,12 @@ class ADURecord(object):
         _writeline(sio, self._data)
         return sio.getvalue()
 
-    def to_list(self):
-        return _tolist(self._data)
+    def to_list(self, truncate_long_values=False):
+        """
+        if truncate_long_fields is False, raises an exception if any are too
+        long.
+        """
+        return _tolist(self._data, truncate_long_values)
 
     def get_summary(self):
         """
@@ -112,6 +120,3 @@ if __name__=='__main__':
             print '-------'
         for k, v in sorted(rec.get_summary().iteritems()):
             print "%s: %s" % (k, v)
-    
-
-        
